# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protocol.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'protocol.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eprotocol.proto\x12\x1ckr.jclab.distworker.protocol\x1a\x1cgoogle/protobuf/struct.proto\"1\n\x0eWorkerRegister\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"+\n\x16WorkerRegisterResponse\x12\x11\n\tidle_time\x18\n \x01(\x05\"\x94\x01\n\x14SignedWorkerRegister\x12\x18\n\x10provisioner_name\x18\x01 \x01(\t\x12\x11\n\tworker_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x41\n\rresource_info\x18\x04 \x01(\x0b\x32*.kr.jclab.distworker.protocol.ResourceInfo\"\xca\x01\n\nTaskAssign\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05input\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ntimeout_ms\x18\x05 \x01(\x03\x12\x35\n\x05\x66iles\x18\x06 \x03(\x0b\x32&.kr.jclab.distworker.protocol.FileInfo\"i\n\x0cTaskProgress\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x02\x12\x0f\n\x07message\x18\x03 \x01(\t\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x86\x01\n\x0cTaskComplete\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\'\n\x06result\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0cresult_files\x18\x03 \x03(\x0b\x32&.kr.jclab.distworker.protocol.FileInfo\"x\n\nTaskFailed\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\nerror_code\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12.\n\rerror_details\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x9f\x01\n\tHeartbeat\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12:\n\x06health\x18\x02 \x01(\x0e\x32*.kr.jclab.distworker.protocol.WorkerHealth\x12\x43\n\x0eresource_usage\x18\x03 \x01(\x0b\x32+.kr.jclab.distworker.protocol.ResourceUsage\"s\n\x0cResourceInfo\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x11\n\tcpu_cores\x18\x02 \x01(\x05\x12\x11\n\tmemory_mb\x18\x03 \x01(\x03\x12+\n\nadditional\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x82\x01\n\rResourceUsage\x12\x13\n\x0b\x63pu_percent\x18\x01 \x01(\x02\x12\x16\n\x0ememory_used_mb\x18\x02 \x01(\x03\x12\x17\n\x0fgpu_utilization\x18\x03 \x01(\x02\x12+\n\nadditional\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x08\x46ileInfo\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x13\n\x0bstorage_url\x18\x05 \x01(\t\"\xc3\x04\n\x10WebSocketMessage\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).kr.jclab.distworker.protocol.MessageType\x12G\n\x0fworker_register\x18\x02 \x01(\x0b\x32,.kr.jclab.distworker.protocol.WorkerRegisterH\x00\x12X\n\x18worker_register_response\x18\x03 \x01(\x0b\x32\x34.kr.jclab.distworker.protocol.WorkerRegisterResponseH\x00\x12<\n\theartbeat\x18\t \x01(\x0b\x32\'.kr.jclab.distworker.protocol.HeartbeatH\x00\x12?\n\x0btask_assign\x18\n \x01(\x0b\x32(.kr.jclab.distworker.protocol.TaskAssignH\x00\x12\x43\n\rtask_progress\x18\x0b \x01(\x0b\x32*.kr.jclab.distworker.protocol.TaskProgressH\x00\x12\x43\n\rtask_complete\x18\x0c \x01(\x0b\x32*.kr.jclab.distworker.protocol.TaskCompleteH\x00\x12?\n\x0btask_failed\x18\r \x01(\x0b\x32(.kr.jclab.distworker.protocol.TaskFailedH\x00\x42\t\n\x07payload*\x90\x02\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cMESSAGE_TYPE_WORKER_REGISTER\x10\x02\x12)\n%MESSAGE_TYPE_WORKER_REGISTER_RESPONSE\x10\x03\x12\x1a\n\x16MESSAGE_TYPE_HEARTBEAT\x10\t\x12\x1c\n\x18MESSAGE_TYPE_TASK_ASSIGN\x10\n\x12\x1e\n\x1aMESSAGE_TYPE_TASK_PROGRESS\x10\x0b\x12\x1e\n\x1aMESSAGE_TYPE_TASK_COMPLETE\x10\x0c\x12\x1c\n\x18MESSAGE_TYPE_TASK_FAILED\x10\r*s\n\x0cWorkerHealth\x12\x1d\n\x19WORKER_HEALTH_UNSPECIFIED\x10\x00\x12\x14\n\x10WORKER_HEALTH_UP\x10\x01\x12\x16\n\x12WORKER_HEALTH_DOWN\x10\x02\x12\x16\n\x12WORKER_HEALTH_WARN\x10\x03*\xac\x01\n\nTaskStatus\x12\x1b\n\x17TASK_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13TASK_STATUS_PENDING\x10\x01\x12\x1a\n\x16TASK_STATUS_PROCESSING\x10\x02\x12\x19\n\x15TASK_STATUS_COMPLETED\x10\x03\x12\x16\n\x12TASK_STATUS_FAILED\x10\x04\x12\x19\n\x15TASK_STATUS_CANCELLED\x10\x05\x42\x30Z.github.com/jc-lab/distworker/internal/protocolb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protocol_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jc-lab/distworker/internal/protocol'
  _globals['_MESSAGETYPE']._serialized_start=1995
  _globals['_MESSAGETYPE']._serialized_end=2267
  _globals['_WORKERHEALTH']._serialized_start=2269
  _globals['_WORKERHEALTH']._serialized_end=2384
  _globals['_TASKSTATUS']._serialized_start=2387
  _globals['_TASKSTATUS']._serialized_end=2559
  _globals['_WORKERREGISTER']._serialized_start=78
  _globals['_WORKERREGISTER']._serialized_end=127
  _globals['_WORKERREGISTERRESPONSE']._serialized_start=129
  _globals['_WORKERREGISTERRESPONSE']._serialized_end=172
  _globals['_SIGNEDWORKERREGISTER']._serialized_start=175
  _globals['_SIGNEDWORKERREGISTER']._serialized_end=323
  _globals['_TASKASSIGN']._serialized_start=326
  _globals['_TASKASSIGN']._serialized_end=528
  _globals['_TASKPROGRESS']._serialized_start=530
  _globals['_TASKPROGRESS']._serialized_end=635
  _globals['_TASKCOMPLETE']._serialized_start=638
  _globals['_TASKCOMPLETE']._serialized_end=772
  _globals['_TASKFAILED']._serialized_start=774
  _globals['_TASKFAILED']._serialized_end=894
  _globals['_HEARTBEAT']._serialized_start=897
  _globals['_HEARTBEAT']._serialized_end=1056
  _globals['_RESOURCEINFO']._serialized_start=1058
  _globals['_RESOURCEINFO']._serialized_end=1173
  _globals['_RESOURCEUSAGE']._serialized_start=1176
  _globals['_RESOURCEUSAGE']._serialized_end=1306
  _globals['_FILEINFO']._serialized_start=1308
  _globals['_FILEINFO']._serialized_end=1410
  _globals['_WEBSOCKETMESSAGE']._serialized_start=1413
  _globals['_WEBSOCKETMESSAGE']._serialized_end=1992
# @@protoc_insertion_point(module_scope)
